/* ######################################################################### */
/* ##                                                                     ## */
/* ##  D B T U T O O L S / D B T U P R E P T I M E . C                    ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Job .......: Program that converts an given consistency token into ## */
/* ##               an timestamp.                                         ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Copyright (C) 2002  Daniel Scheibli                                ## */
/* ##                                                                     ## */
/* ##  This program is free software; you can redistribute it and/or      ## */
/* ##  modify it under the terms of the GNU General Public License        ## */
/* ##  as published by the Free Software Foundation; either version 2     ## */
/* ##  of the License, or (at your option) any later version.             ## */
/* ##                                                                     ## */
/* ##  This program is distributed in the hope that it will be useful,    ## */
/* ##  but WITHOUT ANY WARRANTY; without even the implied warranty of     ## */
/* ##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      ## */
/* ##  GNU General Public License for more details.                       ## */
/* ##                                                                     ## */
/* ##  You should have received a copy of the GNU General Public License  ## */
/* ##  along with this program; if not, write to the Free Software        ## */
/* ##  Foundation, Inc., 59 Temple Place - Suite 330, Boston,             ## */
/* ##  MA  02111-1307, USA.                                               ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Author ....: Daniel Scheibli <daniel.scheibli@edelbyte.org>        ## */
/* ##  Date ......: 2002-04-23                                            ## */
/* ##  Changes ...: ----- dbtupreptime.c V00.99/R002 -------------------- ## */
/* ##               2002-05-12 - Move of conversion function to the       ## */
/* ##                            central codefile.                        ## */
/* ##               2002-05-12 - Shift to central headerfile.             ## */
/* ##               2002-05-07 - Change from printf() to fprintf().       ## */
/* ##               ----- dbtupreptime.c V00.99/R001 -------------------- ## */
/* ##               <none>                                                ## */
/* ##                                                                     ## */
/* ######################################################################### */



/* ##### Presettings */
/* ------------------------------------------------------------------------- */
#include "libdbtubase.h"
/* ------------------------------------------------------------------------- */





/* ######################################################################### */
/* ##                                                                     ## */
/* ##   < M A I N >                                                       ## */
/* ##                                                                     ## */
/* ######################################################################### */
int main( int argc, char *argv[] )
{
 /* ##### Presettings */
 /* ------------------------------------------------------------------------ */
 char *pcTimestamp = NULL;
 /* ------------------------------------------------------------------------ */



 /* ##### Check the given arguments */
 /* ------------------------------------------------------------------------ */
 if( argc != 2 )
 {
  fprintf(STDERR, "%s",                                                       NEWLINE);
  fprintf(STDERR, "===> ERROR: A minimum of one argument was expected.%s",    NEWLINE);
  fprintf(STDERR, "     [%s (%i)]%s", __FILE__, __LINE__,                     NEWLINE);
  fprintf(STDERR, "%s",                                                       NEWLINE);
  fprintf(STDERR, "Usage .......: >>--- dbtupreptime ---- CT ---><%s",        NEWLINE);
  fprintf(STDERR, "%s",                                                       NEWLINE);
  fprintf(STDERR, "Sample ......: dbtupreptime aAiXVXES%s",                   NEWLINE);  
  fprintf(STDERR, "%s",                                                       NEWLINE);
  fprintf(STDERR, "Arguments ...: CT   The Consistency Token which should%s", NEWLINE);  
  fprintf(STDERR, "                    be converted into a timestamp.%s",     NEWLINE);  
  fprintf(STDERR, "%s",                                                       NEWLINE);
  return(1);
 }
 /* ------------------------------------------------------------------------ */ 



 /* ##### Convert the given Consistency Token */
 /* ------------------------------------------------------------------------ */ 
 pcTimestamp = Dbtu_Converter_ConsistencyToken2Timestamp(argv[1]);
 if( pcTimestamp == NULL )
 {
  fprintf(STDERR, "%s",                                                    NEWLINE);
  fprintf(STDERR, "===> ERROR: Conversion of Consistency Token failed.%s", NEWLINE);
  fprintf(STDERR, "     [%s (%i)]%s", __FILE__, __LINE__,                  NEWLINE);
  fprintf(STDERR, "%s",                                                    NEWLINE);
  return(1);
 }
 /* ------------------------------------------------------------------------ */  
 


 /* ##### Print the conversion result */
 /* ------------------------------------------------------------------------ */  
 fprintf(STDOUT, "%s",                                                   NEWLINE);
 fprintf(STDOUT, "The consistency token stands for '%s'%s", pcTimestamp, NEWLINE);
 fprintf(STDOUT, "%s",                                                   NEWLINE);
 free(pcTimestamp);
 /* ------------------------------------------------------------------------ */  



 /* ##### End the program */
 /* ------------------------------------------------------------------------ */ 
 return(0);
 /* ------------------------------------------------------------------------ */ 
}




