/* ######################################################################### */
/* ##                                                                     ## */
/* ##  D B T U T O O L S / C O R E / A P I W R A P P E R . J A V A        ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Job .......: Wrapper class, covering the dbtuapiwrapper binary.    ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Copyright (C) 2002  Daniel Scheibli                                ## */
/* ##                                                                     ## */
/* ##  This library is free software; you can redistribute it and/or      ## */
/* ##  modify it under the terms of the GNU Lesser General Public         ## */
/* ##  License as published by the Free Software Foundation; either       ## */
/* ##  version 2.1 of the License, or (at your option) any later version. ## */
/* ##                                                                     ## */
/* ##  This library is distributed in the hope that it will be useful,    ## */
/* ##  but WITHOUT ANY WARRANTY; without even the implied warranty of     ## */
/* ##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU  ## */
/* ##  Lesser General Public License for more details.                    ## */
/* ##                                                                     ## */
/* ##  You should have received a copy of the GNU Lesser General Public   ## */
/* ##  License along with this library; if not, write to the Free         ## */
/* ##  Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,     ## */
/* ##  MA 02111-1307 USA                                                  ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Remark ....: <none>                                                ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Author ....: Daniel Scheibli <daniel.scheibli@edelbyte.org>        ## */
/* ##  Date ......: 2003-01-19                                            ## */
/* ##  Changes ...: ----- ApiWrapper.java V00.99/R020 ------------------- ## */
/* ##               <none>                                                ## */
/* ##                                                                     ## */
/* ######################################################################### */



/* ##### Presettings */
/* ------------------------------------------------------------------------- */
package org.dbtutools.DbtuTools.core;
/* ------------------------------------------------------------------------- */





/* ##### Class definition */
/** ************************************************************************
 * Wrapper class, covers the dbtuapiwrapper binary related stuff.
 * It can not be instantiated.<br />
 * <br />
 * <i>Remark:</i> Please notice, that core processes and utilities should
 * not use methods of this class directly. Use the theme oriented class
 * methods instead (for example
 * {@link org.dbtutools.DbtuTools.core.os.System#getEndianType()}
 * instead of {@link #getEndianType()}).
 *
 * @author Daniel Scheibli &lt;daniel.scheibli at edelbyte.org&gt;
 * ************************************************************************* */
public class ApiWrapper
{
 /* ##### Presettings (class fields) */
 /* ------------------------------------------------------------------------ */
 /** ***********************************************************************
  * Constant standing for all little endian platforms as systems
  * with Intel x86 processor(s) are.
  * ************************************************************************ */ 
 public static final int ENDIAN_TYPE_LITTLE = 0; 
 /** ***********************************************************************
  * Constant standing for all big endian platforms as most
  * RISC machines are.
  * ************************************************************************ */ 
 public static final int ENDIAN_TYPE_BIG    = 1; 
 /* ------------------------------------------------------------------------ */ 





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   A P I W R A P P E R ()                                           ## */
 /* ##                                                                    ## */ 
 /* ######################################################################## */
 /** ***********************************************************************
  * Private declared Constructor, preventing the instantiation
  * of the <code>ApiWrapper</code> class.
  * ************************************************************************ */
 private ApiWrapper( )
 { }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   G E T E N D I A N T Y P E ()                                     ## */ 
 /* ##                                                                    ## */
 /* ######################################################################## */ 
 /** ***********************************************************************
  * Detects and returns the endian type of the current running
  * platform.<br />
  *
  * @return {@link #ENDIAN_TYPE_LITTLE} - For the case, that a
  *         little endian platform was detected.
  *         <br>
  *         {@link #ENDIAN_TYPE_BIG} - For the case, that a
  *         big endian platform was detected.
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the endian type could
  *            not be detected.<BR>
  * ************************************************************************ */
 public static int getEndianType( ) throws org.edelbyte.util.UnknownValueException
 {
  /* ##### Presettings */
  /* ----------------------------------------------------------------------- */ 
  java.lang.String       oPathNameToken = org.dbtutools.DbtuTools.core.OptDbtuToolsTree.getInstance().getPathNames().get("Tree.Instance.Bin").toString();
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  java.lang.StringBuffer oCallString    = new java.lang.StringBuffer();
  java.lang.Process      oProcess;
  java.io.BufferedReader oOutputStream;
  java.lang.String       oOutputRow     = "";
  /* ----------------------------------------------------------------------- */   



  /* ##### Assemble the call string */
  /* ----------------------------------------------------------------------- */
  oCallString.append( oPathNameToken ).append( java.io.File.separator );
  oCallString.append( "dbtuapiwrapper --request core.os.system.getendiantype" );
  /* ----------------------------------------------------------------------- */



  /* ##### Execute the call string */
  /* ----------------------------------------------------------------------- */
  try
  {
   oProcess      = java.lang.Runtime.getRuntime().exec( oCallString.toString() );
   oOutputStream = new java.io.BufferedReader( new java.io.InputStreamReader( oProcess.getInputStream() ) );
   oOutputRow    = oOutputStream.readLine();
   oProcess.waitFor();
  }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  catch( java.io.IOException oException )
  { throw new org.edelbyte.util.UnknownValueException( "While executing the API wrapper an IOException was thrown." ); }
  catch( java.lang.InterruptedException oException )
  { throw new org.edelbyte.util.UnknownValueException( "While executing the API wrapper an InterruptedException was thrown." ); }
  /* ----------------------------------------------------------------------- */



  /* ##### Process and return the execution result */
  /* ----------------------------------------------------------------------- */
  if( oProcess.exitValue() != 0 )
  { throw new org.edelbyte.util.UnknownValueException( "API wrapper returned with error code " + oProcess.exitValue() + "." ); }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  if( oOutputRow.compareToIgnoreCase( "little" ) == 0 )
  { return( ENDIAN_TYPE_LITTLE ); }
  if( oOutputRow.compareToIgnoreCase( "big" ) == 0 )   
  { return( ENDIAN_TYPE_BIG ); }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */  
  throw new org.edelbyte.util.UnknownValueException( "API wrapper returned no endian type or used an unknown format." );
  /* ----------------------------------------------------------------------- */
 }
}
/* ------------------------------------------------------------------------- */




