/* ######################################################################### */
/* ##                                                                     ## */
/* ##  U T I L / S Y S T E M . J A V A                                    ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Job .......: Class providing Operating System related methods.     ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Copyright (C) 2002  Daniel Scheibli                                ## */
/* ##                                                                     ## */
/* ##  This library is free software; you can redistribute it and/or      ## */
/* ##  modify it under the terms of the GNU Lesser General Public         ## */
/* ##  License as published by the Free Software Foundation; either       ## */
/* ##  version 2.1 of the License, or (at your option) any later version. ## */
/* ##                                                                     ## */
/* ##  This library is distributed in the hope that it will be useful,    ## */
/* ##  but WITHOUT ANY WARRANTY; without even the implied warranty of     ## */
/* ##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU  ## */
/* ##  Lesser General Public License for more details.                    ## */
/* ##                                                                     ## */
/* ##  You should have received a copy of the GNU Lesser General Public   ## */
/* ##  License along with this library; if not, write to the Free         ## */
/* ##  Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,     ## */
/* ##  MA 02111-1307 USA                                                  ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Remark ....: <none>                                                ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Author ....: Daniel Scheibli <daniel.scheibli@edelbyte.org>        ## */
/* ##  Date ......: 2002-10-10                                            ## */
/* ##  Changes ...: ----- System.java V00.99/R020 ----------------------- ## */
/* ##               2002-12-20 - Added a lot of new operating systems to  ## */
/* ##                            the getOsFamily() method.                ## */
/* ##               ----- System.java V00.99/R011 ----------------------- ## */
/* ##               <none>                                                ## */
/* ##                                                                     ## */
/* ######################################################################### */



/* ##### Presettings */
/* ------------------------------------------------------------------------- */
package org.edelbyte.util;
/* ------------------------------------------------------------------------- */





/* ##### Class definition */
/** ************************************************************************
 * The <code>System</code> class provides operating system related stuff.
 * It cannot be instantiated.
 * @author Daniel Scheibli &lt;daniel.scheibli at edelbyte.org&gt;
 * ************************************************************************* */
public class System
{
 /* ##### Presettings (class fields) */
 /* ------------------------------------------------------------------------ */
 /** ***********************************************************************
  * Constant standing for all DOS succession operating systems, like
  * the Microsoft Windows family and IBM's OS/2.
  * ************************************************************************ */
 public static final int OS_FAMILY_WINTEL = 0; 
 /** ***********************************************************************
  * Constant standing for the Unix operating systems, like IBM's AIX,
  * Linux, Sun Solaris and others.
  * ************************************************************************ */
 public static final int OS_FAMILY_UNIX   = 1;
 /* ------------------------------------------------------------------------ */ 





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   S Y S T E M ()                                                   ## */
 /* ##                                                                    ## */ 
 /* ######################################################################## */
 /** ***********************************************************************
  * Private declared Constructor, preventing the instantiation
  * of the <code>System</code> class.
  * ************************************************************************ */
 private System( )
 { }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   G E T O S F A M I L Y ()                                         ## */ 
 /* ##                                                                    ## */
 /* ######################################################################## */ 
 /** ***********************************************************************
  * Detects and returns the operating system family.<br />
  * <br />
  * <i>Background:</i> The detection is done by interpreting the
  * value of <code>java.lang.System.getProperty(&quot;os.name&quot;);
  *
  * @return {@link #OS_FAMILY_UNIX} - For the case, that a
  *         Unix family operating system was detected.
  *         <br>
  *         {@link #OS_FAMILY_WINTEL} - For the case, that a
  *         Wintel family operating system was detected.
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the operating system family could
  *            not be detected.<BR>
  * ************************************************************************ */
 public static int getOsFamily( ) throws org.edelbyte.util.UnknownValueException
 {
  /* ##### Presettings */
  /* ----------------------------------------------------------------------- */ 
  java.lang.String oOsName = java.lang.System.getProperty( "os.name" );
  /* ----------------------------------------------------------------------- */   



  /* ##### Map operating system to its family and return the result */
  /* ----------------------------------------------------------------------- */ 
  if( (oOsName.startsWith( "AIX" ))     ||
      (oOsName.startsWith( "FreeBSD" )) ||
      (oOsName.startsWith( "HP-UX" ))   ||
      (oOsName.startsWith( "Linux" ))   ||
      (oOsName.startsWith( "Solaris" )) ||
      (oOsName.startsWith( "SunOS" )) )
  { return( OS_FAMILY_UNIX ); }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  if( (oOsName.startsWith( "OS/2" )) ||
      (oOsName.startsWith( "Windows" )) )
  { return( OS_FAMILY_WINTEL ); }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  throw new org.edelbyte.util.UnknownValueException( "Operating system family is unknown" );
  /* ----------------------------------------------------------------------- */
 }
}
/* ------------------------------------------------------------------------- */




